@@ -5,4 +5,4 @@ from ..models.place import Place
 
 @admin.register(Place)
 class PlaceAdmin(admin.ModelAdmin):
-    list_display = ('name', 'place')
+    list_display = ("name", "place")
