@@ -2,4 +2,4 @@ from .generic import TemplateView
 
 
 class TermsConditionsView(TemplateView):
-    template_name = 'leprikon/terms_conditions.html'
+    template_name = "leprikon/terms_conditions.html"
